Context Managers
================

.. module:: attest.contexts

Attest provides some context managers that are useful for writing tests.

.. autofunction:: raises(\*exceptions)

.. autofunction:: warns(\*warnings, any=False)

.. autofunction:: capture_output()

.. autofunction:: disable_imports(\*names)

.. autofunction:: tempdir()
